@@ -1,43 +1,14 @@
 use v5.26;
 use Object::Pad;
 
-package Blockchain::Ethereum::ABI::TypeRole 0.012;
+package Blockchain::Ethereum::ABI::TypeRole;
 role Blockchain::Ethereum::ABI::TypeRole;
 
-=head2 encode
-
-Encodes the given data to the type of the signature
-
-Usage:
-
-    encode() -> encoded string
-
-=over 4
-
-=back
-
-ABI encoded hex string
-
-=cut
+our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
+our $VERSION   = '0.013';          # VERSION
 
 method encode;
 
-=head2 decode
-
-Decodes the given data to the type of the signature
-
-Usage:
-
-    decoded() -> check the child classes for return type
-
-=over 4
-
-=back
-
-check the child classes for return type
-
-=cut
-
 method decode;
 
 method _configure;
@@ -46,20 +17,50 @@ method _configure;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Blockchain::Ethereum::ABI::TypeRole
+
+=head1 VERSION
+
+version 0.013
+
+=head1 METHODS
+
+=head2 encode
+
+Encodes the given data to the type of the signature
+
+=over 4
+
+=back
+
+ABI encoded hex string
+
+=head2 decode
+
+Decodes the given data to the type of the signature
+
+=over 4
+
+=back
+
+check the child classes for return type
+
 =head1 AUTHOR
 
-Reginaldo Costa, C<< <refeco at cpan.org> >>
+Reginaldo Costa <refeco@cpan.org>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to L<https://github.com/refeco/perl-ABI>
-
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2022 by REFECO.
 
 This is free software, licensed under:
 
-  The MIT License
+  The MIT (X11) License
 
 =cut
